==> odps-center-api-1.1.72-20230711.024527-4-sources.jar: cn/com/duiba/odps/center/api/dto/zyjy/UserDataDto.java <==
package cn.com.duiba.odps.center.api.dto.zyjy;

import java.io.Serializable;

public class UserDataDto implements Serializable {
    private static final long serialVersionUID = -6101339475866269998L;
    private Long id;
    private String projectId;
    private String projectCode;
    private String projectName;
    private String curDate;
    private String partnerUserId;
    private String phone;
    private String userType;
    private String isClient;
    private String firstJoinTime;
    private String firstJoinChannel;
    private Long accessPv;
    private Long joinPv;
    private Long joinDays;
    private Long zlUv;
    private Long spCreditsCnt;
    private Long spGrapeCnt;
    private Long friendsCnt;
    private Long luckyPv;
    private String inviterUid;
    private String inviterName;
    private String agentNo;
    private String agentUid;
    private String gmtCreate;
    private String gmtModified;

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(String gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public String getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(String gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getCurDate() {
        return curDate;
    }

    public void setCurDate(String curDate) {
        this.curDate = curDate;
    }

    public String getPartnerUserId() {
        return partnerUserId;
    }

    public void setPartnerUserId(String partnerUserId) {
        this.partnerUserId = partnerUserId;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getUserType() {
        return userType;
    }

    public void setUserType(String userType) {
        this.userType = userType;
    }

    public String getIsClient() {
        return isClient;
    }

    public void setIsClient(String isClient) {
        this.isClient = isClient;
    }

    public String getFirstJoinTime() {
        return firstJoinTime;
    }

    public void setFirstJoinTime(String firstJoinTime) {
        this.firstJoinTime = firstJoinTime;
    }

    public String getFirstJoinChannel() {
        return firstJoinChannel;
    }

    public void setFirstJoinChannel(String firstJoinChannel) {
        this.firstJoinChannel = firstJoinChannel;
    }

    public Long getAccessPv() {
        return accessPv;
    }

    public void setAccessPv(Long accessPv) {
        this.accessPv = accessPv;
    }

    public Long getJoinPv() {
        return joinPv;
    }

    public void setJoinPv(Long joinPv) {
        this.joinPv = joinPv;
    }

    public Long getJoinDays() {
        return joinDays;
    }

    public void setJoinDays(Long joinDays) {
        this.joinDays = joinDays;
    }

    public Long getZlUv() {
        return zlUv;
    }

    public void setZlUv(Long zlUv) {
        this.zlUv = zlUv;
    }

    public Long getSpCreditsCnt() {
        return spCreditsCnt;
    }

    public void setSpCreditsCnt(Long spCreditsCnt) {
        this.spCreditsCnt = spCreditsCnt;
    }

    public Long getSpGrapeCnt() {
        return spGrapeCnt;
    }

    public void setSpGrapeCnt(Long spGrapeCnt) {
        this.spGrapeCnt = spGrapeCnt;
    }

    public Long getFriendsCnt() {
        return friendsCnt;
    }

    public void setFriendsCnt(Long friendsCnt) {
        this.friendsCnt = friendsCnt;
    }

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public Long getLuckyPv() {
        return luckyPv;
    }

    public void setLuckyPv(Long luckyPv) {
        this.luckyPv = luckyPv;
    }

    public String getInviterUid() {
        return inviterUid;
    }

    public void setInviterUid(String inviterUid) {
        this.inviterUid = inviterUid;
    }

    public String getInviterName() {
        return inviterName;
    }

    public void setInviterName(String inviterName) {
        this.inviterName = inviterName;
    }

    public String getAgentNo() {
        return agentNo;
    }

    public void setAgentNo(String agentNo) {
        this.agentNo = agentNo;
    }

    public String getAgentUid() {
        return agentUid;
    }

    public void setAgentUid(String agentUid) {
        this.agentUid = agentUid;
    }
}

==> odps-center-api-1.3.35-sources.jar: cn/com/duiba/odps/center/api/dto/zyjy/UserDataDto.java <==
package cn.com.duiba.odps.center.api.dto.zyjy;

import java.io.Serializable;

public class UserDataDto implements Serializable {
    private static final long serialVersionUID = -6101339475866269998L;
    /**
     * 主键id
      */
    private Long id;
    /**
     * 项目id
     */
    private String projectId;
    /**
     * 客户侧活动代码
     */
    private String projectCode;
    /**
     * 项目名称
     */
    private String projectName;
    /**
     * 统计时间
     */
    private String curDate;
    /**
     * 用户uid
     */
    private String partnerUserId;
    /**
     * 用户手机号
     */
    private String phone;
    /**
     * 用户类型
     */
    private String userType;
    /**
     * 是否是代理人
     */
    private String isClient;
    /**
     * 首次参与时间
     */
    private String firstJoinTime;
    /**
     * 首次参与平台
     */
    private String firstJoinChannel;
    /**
     * 是否简单参与
     */
    private Long accessPv;
    /**
     * 是否深度参与
     */
    private Long joinPv;
    /**
     * 累计参与天数
     */
    private Long joinDays;
    /**
     * 累计参与人数
     */
    private Long zlUv;
    /**
     * 累计积分数
     */
    private Long spCreditsCnt;
    /**
     * 累计收获数
     */
    private Long spGrapeCnt;
    /**
     * 累计好友数
     */
    private Long friendsCnt;
    /**
     * 终极大奖
     */
    private Long luckyPv;

    /**
     * 邀请人名称
     */
    private String inviterName;
    /**
     * 代理人工号
     */
    private String agentNo;
    /**
     * 代理人uid
     */
    private String agentUid;
    /**
     * 创建时间
     */
    private String gmtCreate;
    /**
     * 修改时间
     */
    private String gmtModified;

    /**
     *  首次参与时间
     */
    private String firstAccessTime;

    /**
     * 邀请代理人工号
     */
    private String inviterAgentCode;
    /**
     * 当前用户的代理人工号
     */
    private String agentCode;

    public String getInviterAgentCode() {
        return inviterAgentCode;
    }

    public void setInviterAgentCode(String inviterAgentCode) {
        this.inviterAgentCode = inviterAgentCode;
    }

    public String getAgentCode() {
        return agentCode;
    }

    public void setAgentCode(String agentCode) {
        this.agentCode = agentCode;
    }

    public String getFirstAccessTime() {
        return firstAccessTime;
    }

    public void setFirstAccessTime(String firstAccessTime) {
        this.firstAccessTime = firstAccessTime;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(String gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public String getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(String gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getCurDate() {
        return curDate;
    }

    public void setCurDate(String curDate) {
        this.curDate = curDate;
    }

    public String getPartnerUserId() {
        return partnerUserId;
    }

    public void setPartnerUserId(String partnerUserId) {
        this.partnerUserId = partnerUserId;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getUserType() {
        return userType;
    }

    public void setUserType(String userType) {
        this.userType = userType;
    }

    public String getIsClient() {
        return isClient;
    }

    public void setIsClient(String isClient) {
        this.isClient = isClient;
    }

    public String getFirstJoinTime() {
        return firstJoinTime;
    }

    public void setFirstJoinTime(String firstJoinTime) {
        this.firstJoinTime = firstJoinTime;
    }

    public String getFirstJoinChannel() {
        return firstJoinChannel;
    }

    public void setFirstJoinChannel(String firstJoinChannel) {
        this.firstJoinChannel = firstJoinChannel;
    }

    public Long getAccessPv() {
        return accessPv;
    }

    public void setAccessPv(Long accessPv) {
        this.accessPv = accessPv;
    }

    public Long getJoinPv() {
        return joinPv;
    }

    public void setJoinPv(Long joinPv) {
        this.joinPv = joinPv;
    }

    public Long getJoinDays() {
        return joinDays;
    }

    public void setJoinDays(Long joinDays) {
        this.joinDays = joinDays;
    }

    public Long getZlUv() {
        return zlUv;
    }

    public void setZlUv(Long zlUv) {
        this.zlUv = zlUv;
    }

    public Long getSpCreditsCnt() {
        return spCreditsCnt;
    }

    public void setSpCreditsCnt(Long spCreditsCnt) {
        this.spCreditsCnt = spCreditsCnt;
    }

    public Long getSpGrapeCnt() {
        return spGrapeCnt;
    }

    public void setSpGrapeCnt(Long spGrapeCnt) {
        this.spGrapeCnt = spGrapeCnt;
    }

    public Long getFriendsCnt() {
        return friendsCnt;
    }

    public void setFriendsCnt(Long friendsCnt) {
        this.friendsCnt = friendsCnt;
    }

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public Long getLuckyPv() {
        return luckyPv;
    }

    public void setLuckyPv(Long luckyPv) {
        this.luckyPv = luckyPv;
    }

    public String getInviterName() {
        return inviterName;
    }

    public void setInviterName(String inviterName) {
        this.inviterName = inviterName;
    }

    public String getAgentNo() {
        return agentNo;
    }

    public void setAgentNo(String agentNo) {
        this.agentNo = agentNo;
    }

    public String getAgentUid() {
        return agentUid;
    }

    public void setAgentUid(String agentUid) {
        this.agentUid = agentUid;
    }
}
